==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/maintenance/kotlin/ConfigurationAssignmentsForResourceGroupArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.maintenance.kotlin

import com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroupArgs.builder
import com.pulumi.azurenative.maintenance.kotlin.inputs.ConfigurationAssignmentFilterPropertiesArgs
import com.pulumi.azurenative.maintenance.kotlin.inputs.ConfigurationAssignmentFilterPropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Configuration Assignment
 * Azure REST API version: 2023-04-01.
 * Other available API versions: 2023-09-01-preview, 2023-10-01-preview.
 * ## Example Usage
 * ### ConfigurationAssignmentsForResourceGroup_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var configurationAssignmentsForResourceGroup = new AzureNative.Maintenance.ConfigurationAssignmentsForResourceGroup("configurationAssignmentsForResourceGroup", new()
 *     {
 *         ConfigurationAssignmentName = "workervmConfiguration",
 *         Filter = new AzureNative.Maintenance.Inputs.ConfigurationAssignmentFilterPropertiesArgs
 *         {
 *             Locations = new[]
 *             {
 *                 "Japan East",
 *                 "UK South",
 *             },
 *             ResourceTypes = new[]
 *             {
 *                 "Microsoft.HybridCompute/machines",
 *                 "Microsoft.Compute/virtualMachines",
 *             },
 *             TagSettings = new AzureNative.Maintenance.Inputs.TagSettingsPropertiesArgs
 *             {
 *                 FilterOperator = AzureNative.Maintenance.TagOperators.Any,
 *                 Tags =
 *                 {
 *                     { "tag1", new[]
 *                     {
 *                         "tag1Value1",
 *                         "tag1Value2",
 *                         "tag1Value3",
 *                     } },
 *                     { "tag2", new[]
 *                     {
 *                         "tag2Value1",
 *                         "tag2Value2",
 *                         "tag2Value3",
 *                     } },
 *                 },
 *             },
 *         },
 *         MaintenanceConfigurationId = "/subscriptions/5b4b650e-28b9-4790-b3ab-ddbd88d727c4/resourcegroups/examplerg/providers/Microsoft.Maintenance/maintenanceConfigurations/configuration1",
 *         ResourceGroupName = "examplerg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/maintenance/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := maintenance.NewConfigurationAssignmentsForResourceGroup(ctx, "configurationAssignmentsForResourceGroup", &maintenance.ConfigurationAssignmentsForResourceGroupArgs{
 * 			ConfigurationAssignmentName: pulumi.String("workervmConfiguration"),
 * 			Filter: maintenance.ConfigurationAssignmentFilterPropertiesResponse{
 * 				Locations: pulumi.StringArray{
 * 					pulumi.String("Japan East"),
 * 					pulumi.String("UK South"),
 * 				},
 * 				ResourceTypes: pulumi.StringArray{
 * 					pulumi.String("Microsoft.HybridCompute/machines"),
 * 					pulumi.String("Microsoft.Compute/virtualMachines"),
 * 				},
 * 				TagSettings: &maintenance.TagSettingsPropertiesArgs{
 * 					FilterOperator: maintenance.TagOperatorsAny,
 * 					Tags: pulumi.StringArrayMap{
 * 						"tag1": pulumi.StringArray{
 * 							pulumi.String("tag1Value1"),
 * 							pulumi.String("tag1Value2"),
 * 							pulumi.String("tag1Value3"),
 * 						},
 * 						"tag2": pulumi.StringArray{
 * 							pulumi.String("tag2Value1"),
 * 							pulumi.String("tag2Value2"),
 * 							pulumi.String("tag2Value3"),
 * 						},
 * 					},
 * 				},
 * 			},
 * 			MaintenanceConfigurationId: pulumi.String("/subscriptions/5b4b650e-28b9-4790-b3ab-ddbd88d727c4/resourcegroups/examplerg/providers/Microsoft.Maintenance/maintenanceConfigurations/configuration1"),
 * 			ResourceGroupName:          pulumi.String("examplerg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroup;
 * import com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroupArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var configurationAssignmentsForResourceGroup = new ConfigurationAssignmentsForResourceGroup("configurationAssignmentsForResourceGroup", ConfigurationAssignmentsForResourceGroupArgs.builder()
 *             .configurationAssignmentName("workervmConfiguration")
 *             .filter(Map.ofEntries(
 *                 Map.entry("locations",
 *                     "Japan East",
 *                     "UK South"),
 *                 Map.entry("resourceTypes",
 *                     "Microsoft.HybridCompute/machines",
 *                     "Microsoft.Compute/virtualMachines"),
 *                 Map.entry("tagSettings", Map.ofEntries(
 *                     Map.entry("filterOperator", "Any"),
 *                     Map.entry("tags", Map.ofEntries(
 *                         Map.entry("tag1",
 *                             "tag1Value1",
 *                             "tag1Value2",
 *                             "tag1Value3"),
 *                         Map.entry("tag2",
 *                             "tag2Value1",
 *                             "tag2Value2",
 *                             "tag2Value3")
 *                     ))
 *                 ))
 *             ))
 *             .maintenanceConfigurationId("/subscriptions/5b4b650e-28b9-4790-b3ab-ddbd88d727c4/resourcegroups/examplerg/providers/Microsoft.Maintenance/maintenanceConfigurations/configuration1")
 *             .resourceGroupName("examplerg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:maintenance:ConfigurationAssignmentsForResourceGroup workervmConfiguration /subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/Microsoft.Maintenance/configurationAssignments/{configurationAssignmentName}
 * ```
 * @property configurationAssignmentName Configuration assignment name
 * @property filter Properties of the configuration assignment
 * @property location Location of the resource
 * @property maintenanceConfigurationId The maintenance configuration Id
 * @property resourceGroupName Resource group name
 * @property resourceId The unique resourceId
 */
public data class ConfigurationAssignmentsForResourceGroupArgs(
    public val configurationAssignmentName: Output<String>? = null,
    public val filter: Output<ConfigurationAssignmentFilterPropertiesArgs>? = null,
    public val location: Output<String>? = null,
    public val maintenanceConfigurationId: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val resourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroupArgs> {
    override fun toJava():
        com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroupArgs =
        com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroupArgs.builder()
            .configurationAssignmentName(configurationAssignmentName?.applyValue({ args0 -> args0 }))
            .filter(filter?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .location(location?.applyValue({ args0 -> args0 }))
            .maintenanceConfigurationId(maintenanceConfigurationId?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConfigurationAssignmentsForResourceGroupArgs].
 */
@PulumiTagMarker
public class ConfigurationAssignmentsForResourceGroupArgsBuilder internal constructor() {
    private var configurationAssignmentName: Output<String>? = null

    private var filter: Output<ConfigurationAssignmentFilterPropertiesArgs>? = null

    private var location: Output<String>? = null

    private var maintenanceConfigurationId: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Configuration assignment name
     */
    @JvmName("nkxaqxtexxoscgww")
    public suspend fun configurationAssignmentName(`value`: Output<String>) {
        this.configurationAssignmentName = value
    }

    /**
     * @param value Properties of the configuration assignment
     */
    @JvmName("oqjmicliybbxaknn")
    public suspend fun filter(`value`: Output<ConfigurationAssignmentFilterPropertiesArgs>) {
        this.filter = value
    }

    /**
     * @param value Location of the resource
     */
    @JvmName("jsasxguahxnmmmcn")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The maintenance configuration Id
     */
    @JvmName("mgasarkluqygjdrm")
    public suspend fun maintenanceConfigurationId(`value`: Output<String>) {
        this.maintenanceConfigurationId = value
    }

    /**
     * @param value Resource group name
     */
    @JvmName("rmuaxryimhnwblsu")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The unique resourceId
     */
    @JvmName("jukaqlhwcvwxxjqu")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Configuration assignment name
     */
    @JvmName("koxtlcaajborugtm")
    public suspend fun configurationAssignmentName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurationAssignmentName = mapped
    }

    /**
     * @param value Properties of the configuration assignment
     */
    @JvmName("pjolbshyfuugdfbk")
    public suspend fun filter(`value`: ConfigurationAssignmentFilterPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filter = mapped
    }

    /**
     * @param argument Properties of the configuration assignment
     */
    @JvmName("syfaimrjsrexgdrc")
    public suspend
    fun filter(argument: suspend ConfigurationAssignmentFilterPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ConfigurationAssignmentFilterPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.filter = mapped
    }

    /**
     * @param value Location of the resource
     */
    @JvmName("apnpltsekdchouas")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The maintenance configuration Id
     */
    @JvmName("bamaodkbjhaidxxl")
    public suspend fun maintenanceConfigurationId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maintenanceConfigurationId = mapped
    }

    /**
     * @param value Resource group name
     */
    @JvmName("fjokbaxqonglrxdr")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The unique resourceId
     */
    @JvmName("dftrydbednqfexyh")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): ConfigurationAssignmentsForResourceGroupArgs =
        ConfigurationAssignmentsForResourceGroupArgs(
            configurationAssignmentName = configurationAssignmentName,
            filter = filter,
            location = location,
            maintenanceConfigurationId = maintenanceConfigurationId,
            resourceGroupName = resourceGroupName,
            resourceId = resourceId,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/maintenance/kotlin/ConfigurationAssignmentsForResourceGroupArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.maintenance.kotlin

import com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroupArgs.builder
import com.pulumi.azurenative.maintenance.kotlin.inputs.ConfigurationAssignmentFilterPropertiesArgs
import com.pulumi.azurenative.maintenance.kotlin.inputs.ConfigurationAssignmentFilterPropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Configuration Assignment
 * Azure REST API version: 2023-04-01.
 * Other available API versions: 2023-09-01-preview, 2023-10-01-preview.
 * ## Example Usage
 * ### ConfigurationAssignmentsForResourceGroup_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var configurationAssignmentsForResourceGroup = new AzureNative.Maintenance.ConfigurationAssignmentsForResourceGroup("configurationAssignmentsForResourceGroup", new()
 *     {
 *         ConfigurationAssignmentName = "workervmConfiguration",
 *         Filter = new AzureNative.Maintenance.Inputs.ConfigurationAssignmentFilterPropertiesArgs
 *         {
 *             Locations = new[]
 *             {
 *                 "Japan East",
 *                 "UK South",
 *             },
 *             ResourceTypes = new[]
 *             {
 *                 "Microsoft.HybridCompute/machines",
 *                 "Microsoft.Compute/virtualMachines",
 *             },
 *             TagSettings = new AzureNative.Maintenance.Inputs.TagSettingsPropertiesArgs
 *             {
 *                 FilterOperator = AzureNative.Maintenance.TagOperators.Any,
 *                 Tags =
 *                 {
 *                     { "tag1", new[]
 *                     {
 *                         "tag1Value1",
 *                         "tag1Value2",
 *                         "tag1Value3",
 *                     } },
 *                     { "tag2", new[]
 *                     {
 *                         "tag2Value1",
 *                         "tag2Value2",
 *                         "tag2Value3",
 *                     } },
 *                 },
 *             },
 *         },
 *         MaintenanceConfigurationId = "/subscriptions/5b4b650e-28b9-4790-b3ab-ddbd88d727c4/resourcegroups/examplerg/providers/Microsoft.Maintenance/maintenanceConfigurations/configuration1",
 *         ResourceGroupName = "examplerg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/maintenance/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := maintenance.NewConfigurationAssignmentsForResourceGroup(ctx, "configurationAssignmentsForResourceGroup", &maintenance.ConfigurationAssignmentsForResourceGroupArgs{
 * 			ConfigurationAssignmentName: pulumi.String("workervmConfiguration"),
 * 			Filter: &maintenance.ConfigurationAssignmentFilterPropertiesArgs{
 * 				Locations: pulumi.StringArray{
 * 					pulumi.String("Japan East"),
 * 					pulumi.String("UK South"),
 * 				},
 * 				ResourceTypes: pulumi.StringArray{
 * 					pulumi.String("Microsoft.HybridCompute/machines"),
 * 					pulumi.String("Microsoft.Compute/virtualMachines"),
 * 				},
 * 				TagSettings: &maintenance.TagSettingsPropertiesArgs{
 * 					FilterOperator: maintenance.TagOperatorsAny,
 * 					Tags: pulumi.StringArrayMap{
 * 						"tag1": pulumi.StringArray{
 * 							pulumi.String("tag1Value1"),
 * 							pulumi.String("tag1Value2"),
 * 							pulumi.String("tag1Value3"),
 * 						},
 * 						"tag2": pulumi.StringArray{
 * 							pulumi.String("tag2Value1"),
 * 							pulumi.String("tag2Value2"),
 * 							pulumi.String("tag2Value3"),
 * 						},
 * 					},
 * 				},
 * 			},
 * 			MaintenanceConfigurationId: pulumi.String("/subscriptions/5b4b650e-28b9-4790-b3ab-ddbd88d727c4/resourcegroups/examplerg/providers/Microsoft.Maintenance/maintenanceConfigurations/configuration1"),
 * 			ResourceGroupName:          pulumi.String("examplerg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroup;
 * import com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroupArgs;
 * import com.pulumi.azurenative.maintenance.inputs.ConfigurationAssignmentFilterPropertiesArgs;
 * import com.pulumi.azurenative.maintenance.inputs.TagSettingsPropertiesArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var configurationAssignmentsForResourceGroup = new ConfigurationAssignmentsForResourceGroup("configurationAssignmentsForResourceGroup", ConfigurationAssignmentsForResourceGroupArgs.builder()
 *             .configurationAssignmentName("workervmConfiguration")
 *             .filter(ConfigurationAssignmentFilterPropertiesArgs.builder()
 *                 .locations(
 *                     "Japan East",
 *                     "UK South")
 *                 .resourceTypes(
 *                     "Microsoft.HybridCompute/machines",
 *                     "Microsoft.Compute/virtualMachines")
 *                 .tagSettings(TagSettingsPropertiesArgs.builder()
 *                     .filterOperator("Any")
 *                     .tags(Map.ofEntries(
 *                         Map.entry("tag1",
 *                             "tag1Value1",
 *                             "tag1Value2",
 *                             "tag1Value3"),
 *                         Map.entry("tag2",
 *                             "tag2Value1",
 *                             "tag2Value2",
 *                             "tag2Value3")
 *                     ))
 *                     .build())
 *                 .build())
 *             .maintenanceConfigurationId("/subscriptions/5b4b650e-28b9-4790-b3ab-ddbd88d727c4/resourcegroups/examplerg/providers/Microsoft.Maintenance/maintenanceConfigurations/configuration1")
 *             .resourceGroupName("examplerg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:maintenance:ConfigurationAssignmentsForResourceGroup workervmConfiguration /subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/Microsoft.Maintenance/configurationAssignments/{configurationAssignmentName}
 * ```
 * @property configurationAssignmentName Configuration assignment name
 * @property filter Properties of the configuration assignment
 * @property location Location of the resource
 * @property maintenanceConfigurationId The maintenance configuration Id
 * @property resourceGroupName Resource group name
 * @property resourceId The unique resourceId
 */
public data class ConfigurationAssignmentsForResourceGroupArgs(
    public val configurationAssignmentName: Output<String>? = null,
    public val filter: Output<ConfigurationAssignmentFilterPropertiesArgs>? = null,
    public val location: Output<String>? = null,
    public val maintenanceConfigurationId: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val resourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroupArgs> {
    override fun toJava():
        com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroupArgs =
        com.pulumi.azurenative.maintenance.ConfigurationAssignmentsForResourceGroupArgs.builder()
            .configurationAssignmentName(configurationAssignmentName?.applyValue({ args0 -> args0 }))
            .filter(filter?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .location(location?.applyValue({ args0 -> args0 }))
            .maintenanceConfigurationId(maintenanceConfigurationId?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConfigurationAssignmentsForResourceGroupArgs].
 */
@PulumiTagMarker
public class ConfigurationAssignmentsForResourceGroupArgsBuilder internal constructor() {
    private var configurationAssignmentName: Output<String>? = null

    private var filter: Output<ConfigurationAssignmentFilterPropertiesArgs>? = null

    private var location: Output<String>? = null

    private var maintenanceConfigurationId: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Configuration assignment name
     */
    @JvmName("amksoehrohiefdsk")
    public suspend fun configurationAssignmentName(`value`: Output<String>) {
        this.configurationAssignmentName = value
    }

    /**
     * @param value Properties of the configuration assignment
     */
    @JvmName("osvxcjiixoynksgb")
    public suspend fun filter(`value`: Output<ConfigurationAssignmentFilterPropertiesArgs>) {
        this.filter = value
    }

    /**
     * @param value Location of the resource
     */
    @JvmName("bkhhrexrbffwadkr")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The maintenance configuration Id
     */
    @JvmName("lwrorpdcmqcjycxa")
    public suspend fun maintenanceConfigurationId(`value`: Output<String>) {
        this.maintenanceConfigurationId = value
    }

    /**
     * @param value Resource group name
     */
    @JvmName("jcknqmwxlqbthnfh")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The unique resourceId
     */
    @JvmName("uxdmyqwkjkuhtcop")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Configuration assignment name
     */
    @JvmName("paphtlclfggjnnwv")
    public suspend fun configurationAssignmentName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurationAssignmentName = mapped
    }

    /**
     * @param value Properties of the configuration assignment
     */
    @JvmName("yxcalyqnfjwbpyau")
    public suspend fun filter(`value`: ConfigurationAssignmentFilterPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filter = mapped
    }

    /**
     * @param argument Properties of the configuration assignment
     */
    @JvmName("xlgsmyabrinuogju")
    public suspend
    fun filter(argument: suspend ConfigurationAssignmentFilterPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ConfigurationAssignmentFilterPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.filter = mapped
    }

    /**
     * @param value Location of the resource
     */
    @JvmName("mpodgbhokffgypvc")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The maintenance configuration Id
     */
    @JvmName("tslffxnexvwmtmhy")
    public suspend fun maintenanceConfigurationId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maintenanceConfigurationId = mapped
    }

    /**
     * @param value Resource group name
     */
    @JvmName("fnipjoxnovqhfkxw")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The unique resourceId
     */
    @JvmName("ukbgobrhkensxlvu")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): ConfigurationAssignmentsForResourceGroupArgs =
        ConfigurationAssignmentsForResourceGroupArgs(
            configurationAssignmentName = configurationAssignmentName,
            filter = filter,
            location = location,
            maintenanceConfigurationId = maintenanceConfigurationId,
            resourceGroupName = resourceGroupName,
            resourceId = resourceId,
        )
}
